@@ -18,10 +18,10 @@
  *
  * DJB 2007 March 18. Previous version is v1.6 of pdlthread.c
  */
-static int *copy_int_array (int *from, int size) {
+static PDL_Index *copy_int_array (PDL_Index *from, int size) {
   int *to;
   Newx (to, size, int);
-  return (int *) CopyD (from, to, size, int);
+  return (PDL_Index *) CopyD (from, to, size, int);
 }
 
 static pdl **copy_pdl_array (pdl **from, int size) {
@@ -30,11 +30,12 @@ static pdl **copy_pdl_array (pdl **from, int size) {
   return (pdl **) CopyD (from, to, size, pdl*);
 }
 
-static void print_iarr(int *iarr, int n) {
+static void print_iarr(PDL_Index *iarr, int n) {
   int i;
   printf("(");
   for (i=0;i<n;i++)
-    printf("%s%d",(i?" ":""),iarr[i]);
+    // printf("%s%d",(i?" ":""),iarr[i]);
+    printf("%s%lld",(i?" ":""),iarr[i]);  // hardwire for test, get from %Config
   printf(")");
 }
 
@@ -73,7 +74,7 @@ void dump_thread(pdl_thread *thread) {
    Input: thread structure
    Outputs: Pointer to pthread-specific offset array (returned by function)
 */
-int *pdl_get_threadoffsp(pdl_thread *thread )
+PDL_Index *pdl_get_threadoffsp(pdl_thread *thread )
 {
   if(thread->gflags & PDL_THREAD_MAGICKED) {
   	int thr = pdl_magic_get_thread(thread->pdls[thread->mag_nthpdl]);
@@ -92,7 +93,7 @@ int *pdl_get_threadoffsp(pdl_thread *thread )
 	    Pthread index for the current pthread   ( nthr supplied and modified by function)
 
 */
-int *pdl_get_threadoffsp_int(pdl_thread *thread, int *nthr, int **inds)
+PDL_Index* pdl_get_threadoffsp_int(pdl_thread *thread, int *nthr, PDL_Index **inds)
 {
   if(thread->gflags & PDL_THREAD_MAGICKED) {
   	int thr = pdl_magic_get_thread(thread->pdls[thread->mag_nthpdl]);
@@ -167,10 +168,11 @@ void pdl_clearthreadstruct(pdl_thread *it) {
    noPthreadFlag is a flag indicating that the pdl thread that called this function is not multiple
      processor threading safe, so no pthreading magic will be added
 */
-void 	pdl_autopthreadmagic( pdl **pdls, int npdls, int * realdims, int* creating, int noPthreadFlag ){
+void 	pdl_autopthreadmagic( pdl **pdls, int npdls, PDL_Index* realdims, PDL_Index* creating, int noPthreadFlag ){
 
-	int j, nthrd, totalDims, *nthreadedDims, **threadedDims, **threadedDimSizes;
-	int largest_nvals = 0;  /* The largest PDL size for all the pdls involvled */
+	int j, nthrd, totalDims, *nthreadedDims, **threadedDims;
+    PDL_Index **threadedDimSizes;
+	PDL_Index largest_nvals = 0;  /* The largest PDL size for all the pdls involvled */
 
 	int t;             /* Thread index for each pdl */
 	int tdimStart;    /* Start of the threaded dims for each pdl */
@@ -220,7 +222,7 @@ void 	pdl_autopthreadmagic( pdl **pdls, int npdls, int * realdims, int* creating
 	/* Build int arrays of threaded dim numbers and sizes for each pdl */
 	nthreadedDims     = (int*)  malloc(sizeof(int)   * (npdls));
 	threadedDims      = (int**) malloc(sizeof(int *) * (npdls));
-	threadedDimSizes  = (int**) malloc(sizeof(int *) * (npdls));
+	threadedDimSizes  = (PDL_Index**) malloc(sizeof(PDL_Index *) * (npdls));
 
 
 	/* Find total number of dims and allocate */
@@ -228,7 +230,7 @@ void 	pdl_autopthreadmagic( pdl **pdls, int npdls, int * realdims, int* creating
 	for(j=0; j<npdls; j++) {
 		if(creating[j]) continue;
 		threadedDims[j]     = (int*) malloc(sizeof(int) * pdls[j]->ndims);
-		threadedDimSizes[j] = (int*) malloc(sizeof(int) * pdls[j]->ndims);
+		threadedDimSizes[j] = (PDL_Index*) malloc(sizeof(PDL_Index) * pdls[j]->ndims);
 	}
 
 
@@ -327,7 +329,7 @@ void 	pdl_autopthreadmagic( pdl **pdls, int npdls, int * realdims, int* creating
  *   (i.e. don't attempt to create multiple posix threads to execute)
  */
 void pdl_initthreadstruct(int nobl,
-	pdl **pdls,int *realdims,int *creating,int npdls,
+	pdl **pdls,PDL_Index *realdims,PDL_Index *creating,int npdls,
 	pdl_errorinfo *info,pdl_thread *thread, char *flags, int noPthreadFlag ) {
 	int i; int j;
 	int ndims=0; int nth;
@@ -434,16 +436,16 @@ void pdl_initthreadstruct(int nobl,
 	thread->ndims = ndims;
 	thread->nimpl = nimpl;
 
-      Newx(thread->inds, thread->ndims * (nthr>0 ? nthr : 1), int); /* Create space for pthread-specific inds (i.e. copy for each pthread)*/
+      Newx(thread->inds, thread->ndims * (nthr>0 ? nthr : 1), PDL_Index); /* Create space for pthread-specific inds (i.e. copy for each pthread)*/
       if(thread->inds == NULL) croak("Failed to allocate memory for thread->inds in pdlthread.c");
 
-      Newx(thread->dims, thread->ndims, int);
+      Newx(thread->dims, thread->ndims, PDL_Index);
       if(thread->dims == NULL) croak("Failed to allocate memory for thread->dims in pdlthread.c");
 
-      Newx(thread->offs, thread->npdls * (nthr>0 ? nthr : 1), int); /* Create space for pthread-specific offs */
+      Newx(thread->offs, thread->npdls * (nthr>0 ? nthr : 1), PDL_Index); /* Create space for pthread-specific offs */
       if(thread->offs == NULL) croak("Failed to allocate memory for thread->offs in pdlthread.c");
 
-      Newx(thread->incs, thread->ndims * npdls, int);
+      Newx(thread->incs, thread->ndims * npdls, PDL_Index);
       if(thread->incs == NULL) croak("Failed to allocate memory for thread->incs in pdlthread.c");
 
       Newx(thread->flags, npdls, char);
@@ -549,7 +551,7 @@ void pdl_initthreadstruct(int nobl,
 	PDLDEBUG_f(dump_thread(thread);)
 }
 
-void pdl_thread_create_parameter(pdl_thread *thread,int j,int *dims,
+void pdl_thread_create_parameter(pdl_thread *thread,int j,PDL_Index *dims,
 				 int temp)
 {
 	int i;
@@ -581,8 +583,8 @@ See the manual for why this is impossible");
 int pdl_startthreadloop(pdl_thread *thread,void (*func)(pdl_trans *),
 			pdl_trans *t) {
 	int i,j;
-	int *offsp; int nthr;
-	int *inds;
+	PDL_Index *offsp; int nthr;
+	PDL_Index *inds;
 	if(  (thread->gflags & (PDL_THREAD_MAGICKED | PDL_THREAD_MAGICK_BUSY))
 	     == PDL_THREAD_MAGICKED ) {
 
@@ -617,8 +619,8 @@ int pdl_iterthreadloop(pdl_thread *thread,int nth) {
 	int i,j;
 	int stop = 0;
 	int stopdim;
-	int *offsp; int nthr;
-	int *inds;
+	PDL_Index *offsp; int nthr;
+	PDL_Index *inds;
 	offsp = pdl_get_threadoffsp_int(thread,&nthr, &inds);
 	for(j=0; j<thread->npdls; j++)
 		offsp[j] = PDL_TREPROFFS(thread->pdls[j],thread->flags[j]);
